@@ -7,8 +7,7 @@
 """Extractors for https://everia.club"""
 
 from .common import Extractor, Message
-from .. import text
-import re
+from .. import text, util
 
 BASE_PATTERN = r"(?:https?://)?everia\.club"
 
@@ -26,13 +25,13 @@ class EveriaExtractor(Extractor):
         return self._pagination(self.groups[0])
 
     def _pagination(self, path, params=None, pnum=1):
-        find_posts = re.compile(r'thumbnail">\s*<a href="([^"]+)').findall
+        find_posts = util.re(r'thumbnail">\s*<a href="([^"]+)').findall
 
         while True:
             if pnum == 1:
-                url = "{}{}/".format(self.root, path)
+                url = f"{self.root}{path}/"
             else:
-                url = "{}{}/page/{}/".format(self.root, path, pnum)
+                url = f"{self.root}{path}/page/{pnum}/"
             response = self.request(url, params=params, allow_redirects=False)
 
             if response.status_code >= 300:
@@ -50,16 +49,16 @@ class EveriaPostExtractor(EveriaExtractor):
     example = "https://everia.club/0000/00/00/TITLE"
 
     def items(self):
-        url = self.root + self.groups[0]
+        url = self.root + self.groups[0] + "/"
         page = self.request(url).text
         content = text.extr(page, 'itemprop="text">', "<h3")
-        urls = re.findall(r'img.*?src="([^"]+)', content)
+        urls = util.re(r'img.*?lazy-src="([^"]+)').findall(content)
 
         data = {
             "title": text.unescape(
                 text.extr(page, 'itemprop="headline">', "</h")),
             "tags": list(text.extract_iter(page, 'rel="tag">', "</a>")),
-            "post_url": url,
+            "post_url": text.unquote(url),
             "post_category": text.extr(
                 page, "post-in-category-", " ").capitalize(),
             "count": len(urls),
@@ -67,6 +66,7 @@ class EveriaPostExtractor(EveriaExtractor):
 
         yield Message.Directory, data
         for data["num"], url in enumerate(urls, 1):
+            url = text.unquote(url)
             yield Message.Url, url, text.nameext_from_url(url, data)
 
 
